@@ -25,7 +25,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 namespace Gwenview
 {
-
 namespace RenderingIntent
 {
 /**
@@ -33,7 +32,7 @@ namespace RenderingIntent
  */
 enum Enum : cmsUInt32Number {
     Perceptual = INTENT_PERCEPTUAL,
-    Relative = INTENT_RELATIVE_COLORIMETRIC
+    Relative = INTENT_RELATIVE_COLORIMETRIC,
 };
 
 } // namespace RenderingIntent
